#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: monsterz
# PROJECT HOMEPAGE 	: http://sam.zoy.org/monsterz/
# SOURCE           	: http://sam.zoy.org/monsterz/
#
# AUTHOR         	: skywatcher (s.skywatcher|AT|gmail|DOT|com, simone antoniucci)
# LATEST REVISION	: 2009-03-07
#
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables
set -u

### Setting main variables
NAME="monsterz"
VERSION="0.7.1"
ARCH="i486"
CPU="i686"
BUILD=60.1

HOMEPAGE="http://sam.zoy.org/monsterz/"
DESCRIPTION="Arcade puzzle game"
SRCLNK="http://sam.zoy.org/monsterz/$NAME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERSION
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
ADD=Makefile
ADDLNK=$URL/$ADD
PATCH="monsterz-0.7.1-blit-crash.patch"
PATCHLNK=$URL/$PATCH
DOCS="AUTHORS COPYING INSTALL README TODO"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Checking if Makefile is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Makefile is already present, no need to download it";
else
 	echo "Downloading Makelfile..."
	wget -c -nv $ADDLNK
fi

### Checking if patch is present. If it's not, download it
if [ -f $PATCH ]; then
	echo "Patch is already present, no need to download it";
else
 	echo "Downloading patch..."
	wget -c -nv $PATCHLNK
fi

### Extracting source
tar xf $SRCPKG

### Configure, make, install
cd $SRCDIR
patch monsterz.py $CWD/$PATCH || exit 1
cp -a ../$ADD .
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

### Adding stuff and build-file to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
cp -a $CWD/$ADD $PKGDIR/usr/src/$NAME-$VERSION
cp -a $CWD/$PATCH $PKGDIR/usr/src/$NAME-$VERSION

### Slack-desc 
cat > $PKGDIR/install/slack-desc << EOF
     |-----handy-ruler------------------------------------------------------|
$NAME: $NAME - $DESCRIPTION
$NAME: 
$NAME: Monsterz is a little arcade puzzle game, similar to the famous 
$NAME: Bejeweled or Zookeeper. The goal of the game is to create rows of 
$NAME: similar monsters, either horizontally or vertically. The only
$NAME: allowed move is the swap of two adjacent monsters, on the condition 
$NAME: that it creates a row of three or more. When alignments are cleared,
$NAME: pieces fall from the top of the screen to fill the board again.
$NAME: Chain reactions earn you even more points.
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
#rm -fr $PKGDIR/usr/share/applications/hydrogen.desktop 
cat > $PKGDIR/usr/share/applications/$NAME.desktop << EOF
[Desktop Entry]
Name=monsterz
Comment=arcade puzzle game
Exec=monsterz
Icon=monsterz
Type=Application
Categories=Game;ArcadeGame;
Terminal=false
StartupNotify=true
Encoding=UTF-8
EOF

### Icon
cd $PKGDIR/usr/share/$NAME/graphics
mogrify -resize 48x48 icon.png
cp -a $PKGDIR/usr/share/$NAME/graphics/icon.png $ICONDIR/$NAME.png || exit 1

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Score file must be writeable by anyone!
chmod a+w $PKGDIR/usr/share/$NAME/scores

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5 file
cd $CWD
md5sum $PKG.tgz > $PKG.md5

### dep file
#~ depfinder $PKG.tgz > $PKG.dep
echo "Numeric,bzip2,coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gdbm,\
libdrm,libjpeg,libpng,libtiff,mesa,ncurses,openssl,perl,pygame,\
python,readline,sdl,smpeg,xcb,xorg-libs,zlib" > $PKG.dep

### txt file
cat $PKGDIR/install/slack-desc > $PKG.txt

### src file
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK $ADDLNK $PATCHLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

#Done. Ciao!
